==================
django-storage-url
==================

|pypi| |build| |coverage|

URL-based Django storage configuration management.

An implementation can be viewed on `aldryn-django <https://github.com/divio/aldryn-django/blob/support/3.1.x/aldryn_django/storage.py#L13>`_.


.. |pypi| image:: https://badge.fury.io/py/django-storage-url.svg
    :target: http://badge.fury.io/py/django-storage-url
.. |build| image:: https://travis-ci.org/divio/django-storage-url.svg?branch=master
    :target: https://travis-ci.org/divio/django-storage-url
.. |coverage| image:: https://codecov.io/gh/divio/django-storage-url/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/divio/django-storage-url

.. |python| image:: https://img.shields.io/badge/python-3.5+-blue.svg
    :target: https://pypi.org/project/django-storage-url/
.. |django| image:: https://img.shields.io/badge/django-2.2,%203.0,%203.1-blue.svg
    :target: https://www.djangoproject.com/

Linting
=======

This project uses [divio/lint](https://github.com/divio/lint):

```bash
make lint
```

Running tests
=============

Tests can be run via ``tox``.
